==> mobiusft-0.5.28.zip: mobiusft-0.5.28/src/mobius/crypt/hash_md5.h <==
#ifndef __MOBIUS_CRYPT_HASH_MD5_H__
#define __MOBIUS_CRYPT_HASH_MD5_H__

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <mobius/crypt/hash_block.h>

namespace mobius
{
namespace crypt
{
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//!\brief MD5 hash function implementation
//!\author Eduardo Aguiar
//!\see RFC 1321
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
class hash_md5 : public hash_block
{
public:
  hash_md5 () noexcept;
  virtual void reset () noexcept override;

private:
  virtual void update_block (const mobius::bytearray&) noexcept override;
  virtual const mobius::bytearray evaluate (const mobius::bytearray&) override;

private:
  std::uint32_t a_;
  std::uint32_t b_;
  std::uint32_t c_;
  std::uint32_t d_;
  std::uint64_t size_;
};

} // crypt namespace
} // mobius namespace

#endif

==> mobiusft-1.2.zip: mobiusft-1.2/src/mobius/crypt/hash_md5.h <==
#ifndef __MOBIUS_CRYPT_HASH_MD5_H__
#define __MOBIUS_CRYPT_HASH_MD5_H__

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <mobius/crypt/hash_block.h>

namespace mobius
{
namespace crypt
{
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief MD5 hash function implementation
//! \author Eduardo Aguiar
//! \see RFC 1321
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
class hash_md5 : public hash_block
{
public:
  hash_md5 () noexcept;

private:
  void _update_block (const mobius::bytearray&) noexcept override final;
  void _reset () noexcept override final;
  const mobius::bytearray _evaluate (const mobius::bytearray&) override final;

private:
  std::uint32_t a_;
  std::uint32_t b_;
  std::uint32_t c_;
  std::uint32_t d_;
  std::uint64_t size_;
};

} // crypt namespace
} // mobius namespace

#endif
